@@ -1,4 +1,3 @@
-from datetime import datetime
 from django import forms
 from django.contrib.auth import authenticate
 from django.utils.encoding import smart_unicode
@@ -7,6 +6,7 @@ from .. import scope
 from ..constants import RESPONSE_TYPE_CHOICES, SCOPES
 from ..forms import OAuthForm, OAuthValidationError
 from ..scope import SCOPE_NAMES
+from ..utils import now
 from .models import Client, Grant, RefreshToken
 
 
@@ -242,7 +242,7 @@ class AuthorizationCodeGrantForm(ScopeMixin, OAuthForm):
 
         try:
             self.cleaned_data['grant'] = Grant.objects.get(
-                code=code, client=self.client, expires__gt=datetime.now())
+                code=code, client=self.client, expires__gt=now())
         except Grant.DoesNotExist:
             raise OAuthValidationError({'error': 'invalid_grant'})
 
