@@ -259,13 +259,8 @@ class Authorize(OAuthView, Mixin):
         authorization_form = self.get_authorization_form(request, client,
             post_data, data)
 
-        if not authorization_form.is_bound:
-            return self.render_to_response({
-                'client': client,
-                'form': authorization_form,
-                'oauth_data': data, })
 
-        if not authorization_form.is_valid():
+        if not authorization_form.is_bound or not authorization_form.is_valid():
             return self.render_to_response({
                 'client': client,
                 'form': authorization_form,
@@ -333,6 +328,7 @@ class AccessToken(OAuthView, Mixin):
     * :attr:`get_authorization_code_grant`
     * :attr:`get_refresh_token_grant`
     * :attr:`get_password_grant`
+    * :attr:`get_access_token`
     * :attr:`create_access_token`
     * :attr:`create_refresh_token`
     * :attr:`invalidate_grant`
@@ -386,6 +382,14 @@ class AccessToken(OAuthView, Mixin):
         """
         raise NotImplementedError
 
+    def get_access_token(self, request, user, scope, client):
+        """
+        Override to handle fetching of an existing access token.
+
+        :return: ``object`` - Access token
+        """
+        raise NotImplementedError
+
     def create_access_token(self, request, user, scope, client):
         """
         Override to handle access token creation.
@@ -459,9 +463,12 @@ class AccessToken(OAuthView, Mixin):
         """
         grant = self.get_authorization_code_grant(request, request.POST,
                 client)
-        at = self.create_access_token(request, grant.user, grant.scope, client)
-        rt = self.create_refresh_token(request, grant.user, grant.scope, at,
-                client)
+        if constants.SINGLE_ACCESS_TOKEN:
+            at = self.get_access_token(request, grant.user, grant.scope, client)
+        else:
+            at = self.create_access_token(request, grant.user, grant.scope, client)
+            rt = self.create_refresh_token(request, grant.user, grant.scope, at,
+                    client)
 
         self.invalidate_grant(grant)
 
@@ -491,8 +498,11 @@ class AccessToken(OAuthView, Mixin):
         user = data.get('user')
         scope = data.get('scope')
 
-        at = self.create_access_token(request, user, scope, client)
-        rt = self.create_refresh_token(request, user, scope, at, client)
+        if constants.SINGLE_ACCESS_TOKEN:
+            at = self.get_access_token(request, user, scope, client)
+        else:
+            at = self.create_access_token(request, user, scope, client)
+            rt = self.create_refresh_token(request, user, scope, at, client)
 
         return self.access_token_response(at)
 
